#!/usr/bin/env ruby
require("gsl")

x = Vector.linspace(0, 2*M_PI, 20)
f = Function.new { |x|
  Sf::sin(x)
}

f.graph(x, "-T X -g 3 -C -L 'sin(x)'")

